﻿using System;
using Windows.ApplicationModel.Background;
using Windows.Devices.Gpio;
using System.Diagnostics;

// The Background Application template is documented at http://go.microsoft.com/fwlink/?LinkID=533884&clcid=0x409

namespace Digital2
{
    public sealed class StartupTask : IBackgroundTask
    {
        // Praxisbeispiel 5-2: Mit Endlosschleife
        // zum Ausführen die folgende Methode in Run umbenennen
        public void Run(IBackgroundTaskInstance taskInstance)
        {
            GpioController gpio = GpioController.GetDefault();

            GpioPin pinSwitch = gpio.OpenPin(26);
            if (pinSwitch.IsDriveModeSupported(GpioPinDriveMode.InputPullUp))
                pinSwitch.SetDriveMode(GpioPinDriveMode.InputPullUp);
            else
                pinSwitch.SetDriveMode(GpioPinDriveMode.Input);
            pinSwitch.DebounceTimeout = TimeSpan.FromMilliseconds(10);

            while (true)
            {
                Debug.WriteLine(pinSwitch.Read());
            }
        }

        // Praxisbeispiel 5-2: Mit Ereignismethode ValueChanged und BackgroundTaskDeferral
        // zum Ausführen die folgende Methode in Run umbenennen
        public void Run2(IBackgroundTaskInstance taskInstance)
        {
            BackgroundTaskDeferral deferral = taskInstance.GetDeferral();

            GpioController gpio = GpioController.GetDefault();

            GpioPin pinSwitch = gpio.OpenPin(26);
            if (pinSwitch.IsDriveModeSupported(GpioPinDriveMode.InputPullUp))
                pinSwitch.SetDriveMode(GpioPinDriveMode.InputPullUp);
            else
                pinSwitch.SetDriveMode(GpioPinDriveMode.Input);
            pinSwitch.DebounceTimeout = TimeSpan.FromMilliseconds(10);

            pinSwitch.ValueChanged += (sender, args) =>
            {
                Debug.WriteLine($"GPIO changing: {args.Edge} Value: {sender.Read()}");
            };
        }

        // Praxisbeispiel 5-3: Mit LED
        // zum Ausführen die folgende Methode in Run umbenennen
        public void Run3(IBackgroundTaskInstance taskInstance)
        {
            BackgroundTaskDeferral deferral = taskInstance.GetDeferral();

            GpioController gpio = GpioController.GetDefault();

            GpioPin pinLED = gpio.OpenPin(4);
            pinLED.Write(GpioPinValue.Low);
            pinLED.SetDriveMode(GpioPinDriveMode.Output);

            GpioPin pinSwitch = gpio.OpenPin(26);
            if (pinSwitch.IsDriveModeSupported(GpioPinDriveMode.InputPullUp))
                pinSwitch.SetDriveMode(GpioPinDriveMode.InputPullUp);
            else
                pinSwitch.SetDriveMode(GpioPinDriveMode.Input);

            pinSwitch.DebounceTimeout = TimeSpan.FromMilliseconds(10);

            pinSwitch.ValueChanged += (sender, args) =>
            {
                // als Taster
                if (args.Edge == GpioPinEdge.FallingEdge)
                    pinLED.Write(GpioPinValue.High);
                else // GpioPinEdge.RisingEdge)
                    pinLED.Write(GpioPinValue.Low);

                // als Schalter
                //if (args.Edge == GpioPinEdge.FallingEdge)
                //{
                //    if (pinLED.Read() == GpioPinValue.High)
                //        pinLED.Write(GpioPinValue.Low);
                //    else
                //        pinLED.Write(GpioPinValue.High);
                //}
            };
        }
    }
}
