﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using Microsoft.IoT.Lightning.Providers;
using Windows.Devices.Pwm;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml;
using Windows.Devices.Pwm.Provider;

// Die Vorlage "Leere Seite" ist unter http://go.microsoft.com/fwlink/?LinkId=402352&clcid=0x409 dokumentiert.

namespace Digital5
{
    /// <summary>
    /// Eine leere Seite, die eigenständig verwendet oder zu der innerhalb eines Rahmens navigiert werden kann.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        private PwmPin pinLED;

        public MainPage()
        {
            this.InitializeComponent();
            initializePWM();
        }

        private async void initializePWM()
        {
            // Provider und Controller aus Microsoft.IoT.Lightning.Providers erzeugen
            if (!LightningProvider.IsLightningEnabled)
            {
                Debug.WriteLine("DMAP driver not registered");
                Application.Current.Exit();
            }
            IPwmProvider pwmProvider = LightningPwmProvider.GetPwmProvider();

            // PWM über Windows.Devices.Pwm einrichten
            IReadOnlyList<PwmController> pwmControllers = await PwmController.GetControllersAsync(pwmProvider);

            PwmController controller = pwmControllers[1];   // 0: PCA9685, 1: Software-PWM
            controller.SetDesiredFrequency(controller.MaxFrequency);

            pinLED = controller.OpenPin(4);
            pinLED.Start();
            pinLED.SetActiveDutyCyclePercentage(0.0);
        }

        private void slider_ValueChanged(object sender, Windows.UI.Xaml.Controls.Primitives.RangeBaseValueChangedEventArgs e)
        {
            pinLED.SetActiveDutyCyclePercentage(e.NewValue / 100.0);
        }
    }
}
