﻿using System;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media.Imaging;

namespace Bus3
{
    public sealed partial class MainPage : Page
    {

        public MainPage()
        {
            this.InitializeComponent();

            BH1750Sensor sensor;

            Loaded += async (sender, e) =>
            {
                sensor = await BH1750Sensor.Create();
                sensor.ValueChanged += Sensor_ValueChanged;
            };
        }

        private void Sensor_ValueChanged(object sender, SensorEventArgs e)
        {
            gaugeLux.Value = e.Value;

            setImage(e.Value);
            setLumen(e.Value);
            setInfo(e.Value);
        }

        private void setImage(double lux)
        {
            if (lux < 0.03)
                image.Source = new BitmapImage(new Uri("ms-appx:///Assets/moon.png"));
            else if (lux < 0.04)
                image.Source = new BitmapImage(new Uri("ms-appx:///Assets/fullmoon.png"));
            else if (lux <= 80)
                image.Source = new BitmapImage(new Uri("ms-appx:///Assets/cloudy.png"));
            else
                image.Source = new BitmapImage(new Uri("ms-appx:///Assets/sunny.png"));
        }

        private void setInfo(double lux)
        {
            info.Text = "Richtwert für ";

            if (lux > 700)
                info.Text += "Sportstätten";
            else if (lux > 500)
                info.Text += "Arbeitszimmer";
            else if (lux > 200)
                info.Text += "Flure";
            else if (lux > 110)
                info.Text += "Badezimmer";
            else if (lux > 75)
                info.Text += "Wohnzimmer";
            else if (lux > 45)
                info.Text += "Schlafzimmer";
            else
                info.Text += "-";
        }

        private void setLumen(double lux)
        {
            // Fläche gem. Abstrahlwinkel und Abstand in m berechnen
            var radiant = (distance.Value / 100) * Math.Tan(DegreeToRadian(radiationAngle.Value / 2));
            var area = Math.PI * Math.Pow(radiant, 2);

            gaugeLumen.Value = lux * area;
        }

        private double DegreeToRadian(double deg)
        {
            return Math.PI / 180.0 * deg;
        }
    }
}
