﻿using System;
using System.Threading.Tasks;
using Windows.Data.Json;
using Windows.Web.Http;

namespace Data3
{
    public class DataPoint
    {
        public DateTimeOffset TimeOfEvent { get; set; }

        public double Value { get; set; }
        public int RawValue { get; set; }
        public double Ratio { get; set; }

        public override string ToString()
        {
            return $"DateTime: {TimeOfEvent} Value: {Value:F2} RawValue: {RawValue} Ratio: {Ratio:F2}";
        }

        static string server = "192.168.1.105";
        static int port = 5984;
        static string database = "sensor";

        public async Task<bool> Insert()
        {
            JsonObject jsonObject = new JsonObject()
            {
                { "TimeOfEvent", JsonValue.CreateStringValue(TimeOfEvent.ToString()) },
                { "Value", JsonValue.CreateNumberValue(Value) },
                { "RawValue", JsonValue.CreateNumberValue(RawValue) },
                { "Ratio", JsonValue.CreateNumberValue(Ratio) }
            };
            string data = jsonObject.Stringify();

            HttpClient client = new HttpClient();
            Uri uri = new Uri($"http://{server}:{port}/{database}/{TimeOfEvent}");
            HttpResponseMessage response = await client.PutAsync(uri, new HttpStringContent(data));

            if (response.StatusCode != HttpStatusCode.Created)
                return false;
            return true;
        }

        public async Task<DataPoint> Read(DateTimeOffset id)
        {
            HttpClient client = new HttpClient();

            Uri uri = new Uri($"http://{server}:{port}/{database}/{id}");
            string data = await client.GetStringAsync(uri);

            var obj = new JsonObject();

            if (JsonObject.TryParse(data, out obj))
            {
                return new DataPoint()
                {
                    TimeOfEvent = DateTime.Parse(obj.GetNamedString("TimeOfEvent")),
                    Value = obj.GetNamedNumber("Value"),
                    RawValue = (int)obj.GetNamedNumber("RawValue"),
                    Ratio = obj.GetNamedNumber("Ratio")
                };
            }
            return null;
        }
    }
}
