﻿using System;
using System.Collections.ObjectModel;
using System.Diagnostics;
using Windows.Devices.Adc;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.Web.Http;
using WinRTXamlToolkit.Controls.DataVisualization.Charting;

namespace Data3
{

    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
            Loaded += MainPage_Loaded;

            (LineChart.Series[0] as LineSeries).ItemsSource = new ObservableCollection<object>();
        }

        private async void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            var controller = (await AdcController.GetControllersAsync(new Mcp3002Provider()))[0];
            var channel = controller.OpenChannel(0);

            var timer = new DispatcherTimer()
            {
                Interval = new TimeSpan(0, 0, 0, 1)
            };

            timer.Tick += async (s, args) =>
            {
                var value = channel.ReadValue();
                var ratio = channel.ReadRatio();
                var temperature = ConvertToCelsius(value);

                var data = new DataPoint
                {
                    TimeOfEvent = DateTime.Now,
                    Value = temperature,
                    RawValue = value,
                    Ratio = ratio
                };

                await data.Insert();
                data = await data.Read(data.TimeOfEvent);
                Debug.WriteLine(data);

                AddDataPoint(temperature);
            };
            timer.Start();
        }

        private void AddDataPoint(double value)
        {
            var lineSeries = LineChart.Series[0] as LineSeries;
            var series = lineSeries.ItemsSource as ObservableCollection<object>;
            series.Add(new
            {
                TimeOfEvent = DateTime.Now,
                Value = value
            });

            // die letzten 50 Messungen anzeigen
            if (series.Count > 50)
                series.RemoveAt(0);
        }

        private double ConvertToCelsius(int value)
        {
            // Formel: http://www.linkerkit.de/index.php?title=KY-013_Temperatur-Sensor_Modul
            var temperature = Math.Log(10000.0 * ((1024.0 / value - 1)));
            temperature = 1 / (0.001129148 + (0.000234125 + (0.0000000876741 * temperature * temperature)) * temperature);
            temperature -= 273.15;    // von Kelvin in Celsius

            return temperature;
        }
    }
}
