﻿using DataProducer;
using Newtonsoft.Json;
using ppatierno.AzureSBLite.Messaging;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Diagnostics;
using System.Text;
using System.Threading.Tasks;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using WinRTXamlToolkit.Controls.DataVisualization.Charting;

namespace Dashboard
{
    public sealed partial class MainPage : Page
    {
        EventHubClient client;
        EventHubReceiver receiver;

        public MainPage()
        {
            this.InitializeComponent();

            Loaded += (s, e) =>
            {
                var connectionString = "TransportType=Amqp;Endpoint=sb://ihsuprodamres053dednamespace.servicebus.windows.net/;SharedAccessKeyName=iothubowner;SharedAccessKey=<Ihr Shared Key>";
                var eventHubName = "<Ihr Eventhub>";

                var factory = MessagingFactory.CreateFromConnectionString(connectionString);

                client = factory.CreateEventHubClient(eventHubName);

                // client.GetRuntimeInformation() nicht vorhanden
                var d2cPartitions = new[] { "0", "1" };

                foreach (string partition in d2cPartitions)
                {
                    Task.Run(() => Receive(partition));
                }

                var timerCache = new DispatcherTimer()
                {
                    Interval = new TimeSpan(0, 0, 0, 5)
                };
                timerCache.Tick += (sender, args) =>
                {
                    if (dataPointsCache.Count > 0)
                    {
                        lock (dataPointsCache)
                        {
                            var dataPoint = dataPointsCache.Dequeue();
                            Refresh(dataPoint);
                        }
                    }
                };
                timerCache.Start();
            };
        }

        Queue<Measurement> dataPointsCache = new Queue<Measurement>();

        private void Receive(string partition)
        {
            receiver = client.GetDefaultConsumerGroup().CreateReceiver(partition, DateTime.UtcNow); // - new TimeSpan(0, 1, 0, 0));
            while (true)
            {
                EventData data = receiver.Receive();

                if (data != null)
                {
                    var receivedData = Encoding.UTF8.GetString(data.GetBytes());
                    var dataPoint = JsonConvert.DeserializeObject<Measurement>(receivedData);

                    Debug.WriteLine($"Partition: {partition}/{data.SequenceNumber} DataPoint: '{dataPoint}'");

                    Task.Run(() => 
                    {
                        lock (dataPointsCache)
                        {
                            dataPointsCache.Enqueue(dataPoint);
                        }
                    });
                }
            }
        }

        Dictionary<string, LineSeries> devices = new Dictionary<string, LineSeries>();

        private void Refresh(Measurement dataPoint)
        {
            LineSeries lineSeries;

            if (devices.ContainsKey(dataPoint.DeviceId))
                lineSeries = devices[dataPoint.DeviceId];
            else
            {
                lineSeries = new LineSeries()
                {
                    IndependentValuePath = "TimeOfEvent",
                    DependentValuePath = "Value",
                    Title = $"{dataPoint.DeviceId}\nin ° Celsius"
                };
                lineSeries.ItemsSource = new ObservableCollection<object>();

                LineChart.Series.Add(lineSeries);

                devices.Add(dataPoint.DeviceId, lineSeries);
            }

            var series = lineSeries.ItemsSource as ObservableCollection<object>;
            series.Add(new
            {
                TimeOfEvent = dataPoint.TimeOfEvent.DateTime,
                Value = dataPoint.Value
            });

            // die letzten 50 Messungen anzeigen
            if (series.Count > 50)
                series.RemoveAt(0);

            info.Text += dataPoint.ToString() + "\n";
        }
    }
}

