﻿using DataProducer;
using Microsoft.Azure.Devices;
using Microsoft.Azure.Devices.Client;
using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;

namespace Simulator
{
    class Program
    {
        class RPi3
        {
            public string DeviceId { get; set; }
            public double Latitude { get; set; }
            public double Longitude { get; set; }
        }
        static void Main(string[] args)
        {
            var devices = new List<RPi3>();
            devices.AddRange(
                new RPi3[] {
                    new RPi3 { DeviceId = "RPi3-1", Latitude = 54.774113147246865, Longitude = 9.449607861461117 },
                    new RPi3 { DeviceId = "RPi3-2", Latitude = 54.774769 , Longitude = 9.451442 },
                    new RPi3 { DeviceId = "RPi3-3", Latitude = 54.775833 , Longitude = 9.45508 },
                    new RPi3 { DeviceId = "RPi3-4", Latitude = 54.774, Longitude = 9.4496078 }
                    }
                );

            while (true)
            {
                int index = new Random().Next(0, devices.Count - 1);
                var device = devices[index];

                Register(device.DeviceId).Wait();

                var dataPoint = new Measurement
                {
                    DeviceId = device.DeviceId,
                    Latitude = device.Latitude,
                    Longitude = device.Longitude,
                    TimeOfEvent = DateTimeOffset.Now,
                    Value = new Random().Next(260, 290) / 10.0
                };
                SendToCloudAsync(dataPoint);
                Console.WriteLine(dataPoint);

                Task.Delay(5000).Wait();
            }
        }

        const string ConnectionIoTString = "HostName=<Ihr Host>;SharedAccessKeyName=iothubowner;SharedAccessKey=<Ihr Shared Key>";

        static DeviceClient deviceClient;

        static private async Task Register(string deviceId)
        {
            var registryManager = RegistryManager.CreateFromConnectionString(ConnectionIoTString);

            var device = await registryManager.GetDeviceAsync(deviceId);
            if (device == null)
            {
                device = new Device(deviceId);
                device = await registryManager.AddDeviceAsync(device);
            }
            if (device.Status == DeviceStatus.Enabled)
            {
                string connectionWithDeviceClient = $"DeviceId={deviceId};{ConnectionIoTString}";
                deviceClient = DeviceClient.CreateFromConnectionString(connectionWithDeviceClient);
            }
        }

        static private async void SendToCloudAsync(Measurement dataPoint)
        {
            var data = JsonConvert.SerializeObject(dataPoint);
            var message = new Microsoft.Azure.Devices.Client.Message(Encoding.UTF8.GetBytes(data));

            await deviceClient.SendEventAsync(message);
        }
    }
}
